kitgit

tirbofish/dropbear · commit

7d770701c8ff7a0af41f9f099cb185954d32c3b8

changed dependency from the egui-dock forks to the normal repositories (publishable)

Unverified

tk <4tkbytes@pm.me> · 2025-11-02 02:19

view full diff

diff --git a/Cargo.toml b/Cargo.toml
index ea72445..ad5298d 100644
--- a/Cargo.toml
+++ b/Cargo.toml
@@ -20,11 +20,11 @@ colored = "3.0"
 crossbeam-channel = "0.5"
 dropbear-engine = { path = "dropbear-engine" }
 egui = "0.32"
-egui-toast-fork = "0.18"
+egui-toast = "0.18"
 egui-wgpu = { version = "0.32" }
 egui-winit = { version = "0.32" }
 egui_dnd = "0.13"
-egui_dock-fork = { version = "0.17", features = ["serde"] }
+egui_dock = { version = "0.17", features = ["serde"] }
 egui_extras = { version = "0.32", features = ["all_loaders"] }
 env_logger = "0.11"
 futures = "0.3"
@@ -42,7 +42,7 @@ rfd = "0.15.4"
 ron = "0.11"
 serde = { version = "1.0.219", features = ["derive"] }
 spin_sleep = "1.3"
-transform-gizmo-egui = { git = "https://github.com/4tkbytes/transform-gizmo"}
+transform-gizmo-egui = { version = "0.7" }
 tokio = { version = "1", features = ["full"] }
 wgpu = "25"
 winit = { version = "0.30", features = [] }
diff --git a/eucalyptus-core/Cargo.toml b/eucalyptus-core/Cargo.toml
index e5b0f7c..86324f3 100644
--- a/eucalyptus-core/Cargo.toml
+++ b/eucalyptus-core/Cargo.toml
@@ -14,9 +14,9 @@ anyhow.workspace = true
 bincode.workspace = true
 chrono.workspace = true
 dropbear-engine.workspace = true
-egui-toast-fork.workspace = true
+egui-toast.workspace = true
 egui.workspace = true
-egui_dock-fork.workspace = true
+egui_dock.workspace = true
 glam.workspace = true
 hecs.workspace = true
 log.workspace = true
diff --git a/eucalyptus-core/src/states.rs b/eucalyptus-core/src/states.rs
index 58e8026..af197d2 100644
--- a/eucalyptus-core/src/states.rs
+++ b/eucalyptus-core/src/states.rs
@@ -9,7 +9,7 @@ use dropbear_engine::model::Model;
 use dropbear_engine::procedural::plane::PlaneBuilder;
 use dropbear_engine::utils::{ResourceReference, ResourceReferenceType};
 use egui::Ui;
-use egui_dock_fork::DockState;
+use egui_dock::DockState;
 use glam::{DQuat, DVec3};
 use once_cell::sync::Lazy;
 use parking_lot::RwLock;
diff --git a/eucalyptus-editor/Cargo.toml b/eucalyptus-editor/Cargo.toml
index ca55172..b18523f 100644
--- a/eucalyptus-editor/Cargo.toml
+++ b/eucalyptus-editor/Cargo.toml
@@ -14,10 +14,10 @@ app_dirs2.workspace = true
 bincode.workspace = true
 bytemuck.workspace = true
 dropbear-engine.workspace = true
-egui-toast-fork.workspace = true
+egui-toast.workspace = true
 egui.workspace = true
 egui_dnd.workspace = true
-egui_dock-fork.workspace = true
+egui_dock.workspace = true
 egui_extras.workspace = true
 gilrs.workspace = true
 git2 = { workspace = true, features = ["vendored-openssl"]}
diff --git a/eucalyptus-editor/src/editor/dock.rs b/eucalyptus-editor/src/editor/dock.rs
index e9d64a5..3012420 100644
--- a/eucalyptus-editor/src/editor/dock.rs
+++ b/eucalyptus-editor/src/editor/dock.rs
@@ -14,7 +14,7 @@ use dropbear_engine::{
     lighting::{Light, LightComponent},
 };
 use egui::{self, CollapsingHeader, Margin, RichText};
-use egui_dock_fork::TabViewer;
+use egui_dock::TabViewer;
 use egui_extras;
 use eucalyptus_core::APP_INFO;
 use eucalyptus_core::spawn::{PendingSpawn, push_pending_spawn};
diff --git a/eucalyptus-editor/src/editor/mod.rs b/eucalyptus-editor/src/editor/mod.rs
index 93c5a98..fa0d1f3 100644
--- a/eucalyptus-editor/src/editor/mod.rs
+++ b/eucalyptus-editor/src/editor/mod.rs
@@ -22,7 +22,7 @@ use dropbear_engine::{
     scene::SceneCommand,
 };
 use egui::{self, Context};
-use egui_dock_fork::{DockArea, DockState, NodeIndex, Style};
+use egui_dock::{DockArea, DockState, NodeIndex, Style};
 use eucalyptus_core::APP_INFO;
 use eucalyptus_core::{
     camera::{CameraComponent, CameraType, DebugCamera},
diff --git a/eucalyptus-editor/src/menu.rs b/eucalyptus-editor/src/menu.rs
index acc2a02..5296756 100644
--- a/eucalyptus-editor/src/menu.rs
+++ b/eucalyptus-editor/src/menu.rs
@@ -6,7 +6,7 @@ use dropbear_engine::{
     scene::{Scene, SceneCommand},
 };
 use egui::{self, FontId, Frame, RichText};
-use egui_toast_fork::{ToastOptions, Toasts};
+use egui_toast::{ToastOptions, Toasts};
 use eucalyptus_core::states::{PROJECT, ProjectConfig};
 use git2::Repository;
 use log::{self, debug};
@@ -366,8 +366,8 @@ impl Scene for MainMenu {
                             &e.to_string()
                         };
 
-                        self.toast.add(egui_toast_fork::Toast {
-                            kind: egui_toast_fork::ToastKind::Error,
+                        self.toast.add(egui_toast::Toast {
+                            kind: egui_toast::ToastKind::Error,
                             text: error_msg.to_string().into(),
                             options: ToastOptions::default()
                                 .duration_in_seconds(8.0)
diff --git a/eucalyptus-editor/src/utils.rs b/eucalyptus-editor/src/utils.rs
index a04d13f..db91457 100644
--- a/eucalyptus-editor/src/utils.rs
+++ b/eucalyptus-editor/src/utils.rs
@@ -2,7 +2,7 @@ use anyhow::anyhow;
 use dropbear_engine::camera::Camera;
 use dropbear_engine::scene::SceneCommand;
 use egui::Context;
-use egui_toast_fork::{Toast, ToastOptions, Toasts};
+use egui_toast::{Toast, ToastOptions, Toasts};
 use eucalyptus_core::states::{PROJECT, ProjectConfig};
 use eucalyptus_core::utils::ProjectProgress;
 use git2::Repository;
@@ -199,7 +199,7 @@ pub fn open_project(
             Err(e) => {
                 if e.to_string().contains("missing field") {
                     toast.add(Toast {
-                        kind: egui_toast_fork::ToastKind::Error,
+                        kind: egui_toast::ToastKind::Error,
                         text: "Project version is not up to date.".into(),
                         options: ToastOptions::default()
                             .duration_in_seconds(5.0)
diff --git a/eucalyptus-core/src/logging.rs b/eucalyptus-core/src/logging.rs
index 650e737..e5802ff 100644
--- a/eucalyptus-core/src/logging.rs
+++ b/eucalyptus-core/src/logging.rs
@@ -10,7 +10,7 @@ use egui::Context;
 use std::fmt::{Display, Formatter};
 
 #[cfg(feature = "editor")]
-use egui_toast_fork::Toasts;
+use egui_toast::Toasts;
 
 use once_cell::sync::Lazy;
 use parking_lot::Mutex;
@@ -62,7 +62,7 @@ pub fn render(context: &Context) {
 ///
 /// This is useful for when there is a fatal error like a missing file cannot be found.
 ///
 /// This macro creates a toast under the [`egui_toast_fork::ToastKind::Error`] and logs
 /// with [`log::error!`]
 #[macro_export]
 macro_rules! fatal {
@@ -72,16 +72,16 @@ macro_rules! fatal {
 
         #[cfg(feature = "editor")]
         {
-            use egui_toast_fork::{Toast, ToastKind};
+            use egui_toast::{Toast, ToastKind};
             use $crate::logging::GLOBAL_TOASTS;
             let mut toasts = GLOBAL_TOASTS.lock();
             toasts.add(Toast {
                 text: _msg.into(),
                 kind: ToastKind::Error,
-                options: egui_toast_fork::ToastOptions::default()
+                options: egui_toast::ToastOptions::default()
                     .duration_in_seconds(3.0)
                     .show_progress(true),
-                style: egui_toast_fork::ToastStyle::default(),
+                style: egui_toast::ToastStyle::default(),
             });
         }
     }};
@@ -91,7 +91,7 @@ macro_rules! fatal {
 ///
 /// This is useful for when loading a save is successful.
 ///
 /// This macro creates a toast under the [`egui_toast_fork::ToastKind::Success`] and logs
 /// with [`log::info!`]
 #[macro_export]
 macro_rules! success {
@@ -101,16 +101,16 @@ macro_rules! success {
 
         #[cfg(feature = "editor")]
         {
-            use egui_toast_fork::{Toast, ToastKind};
+            use egui_toast::{Toast, ToastKind};
             use $crate::logging::GLOBAL_TOASTS;
             let mut toasts = GLOBAL_TOASTS.lock();
             toasts.add(Toast {
                     text: _msg.into(),
                     kind: ToastKind::Success,
-                    options: egui_toast_fork::ToastOptions::default()
+                    options: egui_toast::ToastOptions::default()
                         .duration_in_seconds(3.0)
                         .show_progress(true),
-                    style: egui_toast_fork::ToastStyle::default(),
+                    style: egui_toast::ToastStyle::default(),
                 });
             };
         }
@@ -121,7 +121,7 @@ macro_rules! success {
 ///
 /// This is useful for when there is a non-fatal error like unable to copy.
 ///
 /// This macro creates a toast under the [`egui_toast_fork::ToastKind::Warning`] and logs
 /// with [`log::warn!`]
 #[macro_export]
 macro_rules! warn {
@@ -131,16 +131,16 @@ macro_rules! warn {
 
         #[cfg(feature = "editor")]
         {
-            use egui_toast_fork::{Toast, ToastKind};
+            use egui_toast::{Toast, ToastKind};
             use $crate::logging::GLOBAL_TOASTS;
             let mut toasts = GLOBAL_TOASTS.lock();
             toasts.add(Toast {
                     text: _msg.into(),
                     kind: ToastKind::Warning,
-                    options: egui_toast_fork::ToastOptions::default()
+                    options: egui_toast::ToastOptions::default()
                         .duration_in_seconds(3.0)
                         .show_progress(true),
-                    style: egui_toast_fork::ToastStyle::default(),
+                    style: egui_toast::ToastStyle::default(),
                 });
         }
     }};
@@ -150,7 +150,7 @@ macro_rules! warn {
 ///
 /// This is useful for notifying the user of a change, where it doesn't have to be important.
 ///
 /// This macro creates a toast under the [`egui_toast_fork::ToastKind::Info`] and logs
 /// with [`log::debug!`]
 #[macro_export]
 macro_rules! info {
@@ -160,16 +160,16 @@ macro_rules! info {
 
         #[cfg(feature = "editor")]
         {
-            use egui_toast_fork::{Toast, ToastKind};
+            use egui_toast::{Toast, ToastKind};
             use $crate::logging::GLOBAL_TOASTS;
             let mut toasts = GLOBAL_TOASTS.lock();
             toasts.add(Toast {
                 text: _msg.into(),
                 kind: ToastKind::Info,
-                options: egui_toast_fork::ToastOptions::default()
+                options: egui_toast::ToastOptions::default()
                     .duration_in_seconds(1.0)
                     .show_progress(false),
-                style: egui_toast_fork::ToastStyle::default(),
+                style: egui_toast::ToastStyle::default(),
             });
         }
     }};
@@ -182,7 +182,7 @@ macro_rules! info {
 ///
 /// Its feature-heavy counterpart would be [`crate::success!`].
 ///
 /// It creates a toast under [`egui_toast_fork::ToastKind::Info`].
 #[macro_export]
 macro_rules! info_without_console {
     ($($arg:tt)*) => {
@@ -190,16 +190,16 @@ macro_rules! info_without_console {
 
         #[cfg(feature = "editor")]
         {
-            use egui_toast_fork::{Toast, ToastKind};
+            use egui_toast::{Toast, ToastKind};
             use $crate::logging::GLOBAL_TOASTS;
             let mut toasts = GLOBAL_TOASTS.lock();
             toasts.add(Toast {
                 text: _msg.into(),
                 kind: ToastKind::Info,
-                options: egui_toast_fork::ToastOptions::default()
+                options: egui_toast::ToastOptions::default()
                     .duration_in_seconds(1.0)
                     .show_progress(false),
-                style: egui_toast_fork::ToastStyle::default(),
+                style: egui_toast::ToastStyle::default(),
             });
         }
     };
@@ -212,7 +212,7 @@ macro_rules! info_without_console {
 ///
 /// Its feature-heavy counterpart would be [`crate::success!`].
 ///
 /// It creates a toast under [`egui_toast_fork::ToastKind::Success`].
 #[macro_export]
 macro_rules! success_without_console {
     ($($arg:tt)*) => {
@@ -220,16 +220,16 @@ macro_rules! success_without_console {
 
         #[cfg(feature = "editor")]
         {
-            use egui_toast_fork::{Toast, ToastKind};
+            use egui_toast::{Toast, ToastKind};
             use $crate::logging::GLOBAL_TOASTS;
             let mut toasts = GLOBAL_TOASTS.lock();
             toasts.add(Toast {
                 text: _msg.into(),
                 kind: ToastKind::Success,
-                options: egui_toast_fork::ToastOptions::default()
+                options: egui_toast::ToastOptions::default()
                     .duration_in_seconds(3.0)
                     .show_progress(true),
-                style: egui_toast_fork::ToastStyle::default(),
+                style: egui_toast::ToastStyle::default(),
             });
         }
     };
@@ -242,7 +242,7 @@ macro_rules! success_without_console {
 ///
 /// Its feature-heavy counterpart would be [`crate::warn!`].
 ///
 /// It creates a toast under [`egui_toast_fork::ToastKind::Warning`].
 #[macro_export]
 macro_rules! warn_without_console {
     ($($arg:tt)*) => {
@@ -250,16 +250,16 @@ macro_rules! warn_without_console {
 
         #[cfg(feature = "editor")]
         {
-            use egui_toast_fork::{Toast, ToastKind};
+            use egui_toast::{Toast, ToastKind};
             use $crate::logging::GLOBAL_TOASTS;
             let mut toasts = GLOBAL_TOASTS.lock();
             toasts.add(Toast {
                 text: _msg.into(),
                 kind: ToastKind::Warning,
-                options: egui_toast_fork::ToastOptions::default()
+                options: egui_toast::ToastOptions::default()
                     .duration_in_seconds(3.0)
                     .show_progress(true),
-                style: egui_toast_fork::ToastStyle::default(),
+                style: egui_toast::ToastStyle::default(),
             });
         }
     };
@@ -62,7 +62,7 @@ pub fn render(context: &Context) {
 /// This is useful for when there is a fatal error like a missing file cannot be found.
 ///
-/// This macro creates a toast under the [`egui_toast_fork::ToastKind::Error`] and logs
+/// This macro creates a toast under the [`egui_toast::ToastKind::Error`] and logs
 /// with [`log::error!`]
 #[macro_export]
@@ -91,7 +91,7 @@ macro_rules! fatal {
 /// This is useful for when loading a save is successful.
 ///
-/// This macro creates a toast under the [`egui_toast_fork::ToastKind::Success`] and logs
+/// This macro creates a toast under the [`egui_toast::ToastKind::Success`] and logs
 /// with [`log::info!`]
 #[macro_export]
@@ -121,7 +121,7 @@ macro_rules! success {
 /// This is useful for when there is a non-fatal error like unable to copy.
 ///
-/// This macro creates a toast under the [`egui_toast_fork::ToastKind::Warning`] and logs
+/// This macro creates a toast under the [`egui_toast::ToastKind::Warning`] and logs
 /// with [`log::warn!`]
 #[macro_export]
@@ -150,7 +150,7 @@ macro_rules! warn {
 /// This is useful for notifying the user of a change, where it doesn't have to be important.
 ///
-/// This macro creates a toast under the [`egui_toast_fork::ToastKind::Info`] and logs
+/// This macro creates a toast under the [`egui_toast::ToastKind::Info`] and logs
 /// with [`log::debug!`]
 #[macro_export]
@@ -182,7 +182,7 @@ macro_rules! info {
 /// Its feature-heavy counterpart would be [`crate::success!`].
 ///
-/// It creates a toast under [`egui_toast_fork::ToastKind::Info`].
+/// It creates a toast under [`egui_toast::ToastKind::Info`].
 #[macro_export]
 macro_rules! info_without_console {
@@ -212,7 +212,7 @@ macro_rules! info_without_console {
 /// Its feature-heavy counterpart would be [`crate::success!`].
 ///
-/// It creates a toast under [`egui_toast_fork::ToastKind::Success`].
+/// It creates a toast under [`egui_toast::ToastKind::Success`].
 #[macro_export]
 macro_rules! success_without_console {
@@ -242,7 +242,7 @@ macro_rules! success_without_console {
 /// Its feature-heavy counterpart would be [`crate::warn!`].
 ///
-/// It creates a toast under [`egui_toast_fork::ToastKind::Warning`].
+/// It creates a toast under [`egui_toast::ToastKind::Warning`].
 #[macro_export]
 macro_rules! warn_without_console {